(gallery)=
# Gallery

Examples of napari usage.

```{toctree}
:maxdepth: 1

_tags/tagsindex
```

```{eval-rst}
.. include:: gallery/index.rst
    :start-after: :orphan:
    :end-before: .. toctree::
```
